import org.jbox2d.*;

public class BoxSonic extends Sonic{
    Body body;
    
    BoxSonic(int x, int y, Box2DProcessing box2d){
      super(x, y);
      //BodyDef defines a body class
      BodyDef bd = new BodyDef();
      bd.type = BodyType.DYNAMIC;
      bd.position.set(box2d.coordPixelsToWorld(x, y));
      //the main box2d processor creates the
      //body from a bodyDef
      body = box2d.createBody(bd);
      
      //Shape defines the collision box shape
      PolygonShape sd = new PolygonShape();
      float box2dW = box2d.scalarPixelsToWorld(W/2);
      float box2dH = box2d.scalarPixelsToWorld(H/2);
      sd.setAsBox(box2dW, box2dH);
      
      // Define a fixture
      FixtureDef fd = new FixtureDef();
      fd.shape = sd;
      
      // Parameters that affect physics
      fd.density = 0.5;
      fd.friction = 0.1;
      fd.restitution = 0.9;
      
      // Attach Fixture to Body               
      body.createFixture(fd);
    }
    
    void moveLeft(){
      Vec2 v = new Vec2(-100, 0);
      body.applyLinearImpulse(v, body.getLocalCenter(), true);
    }
    
    void moveRight(){
      Vec2 v = new Vec2(100, 0);
      body.applyLinearImpulse(v, body.getLocalCenter(), true);
    }
    
    void moveUp(){
      Vec2 v = new Vec2(0, 600);
      body.applyLinearImpulse(v, body.getLocalCenter(), true);
    }
    
    void step(){
      showCollisionBox();
      super.step();
      Vec2 pos = box2d.getBodyPixelCoord(body);
      x = (int)pos.x - W/2;
      y = (int)pos.y - H/2;
    }
    void showCollisionBox(){
      float a = body.getAngle();
      //rectMode(CENTER);
      stroke(#000000);
      rect(x,y,W,H);
      //rectMode(CORNER);
    }
}